mapping_types = {
    "STR": "STRING",
    "FLOAT": "FLOAT64",
    "INT": "INT64",
    "DATETIME": "TIMESTAMP"
}
